/**********************************************************\
Original Author: Richard Bateman and Georg Fritzsche

Created:    December 3, 2009
License:    Dual license model; choose one of two:
            New BSD License
            http://www.opensource.org/licenses/bsd-license.php
            - or -
            GNU Lesser General Public License, version 2.1
            http://www.gnu.org/licenses/lgpl-2.1.html

Copyright 2009 PacketPass Inc, Georg Fritzsche,
               Firebreath development team
\**********************************************************/

#include "JSObject.h"
#include "DOM/Document.h"
#include "DOM/Window.h"
#include "variant_list.h"
#include "AdvantageDataSecurityPlugin.h"
#include "SystemHelpers.h"
#include <boost/make_shared.hpp>

#include "AdvantageDataSecurityPluginAPI.h"

AdvantageDataSecurityPluginAPI::AdvantageDataSecurityPluginAPI(const AdvantageDataSecurityPluginPtr& plugin, const FB::BrowserHostPtr& host) : m_host(host), m_pluginWeak(plugin)
{    
    
    registerProperty("pluginPath",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_pluginPath));

	registerProperty("pluginId",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_pluginId));

	registerProperty("getMACAddress",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_MACAddress));

	registerProperty("getVersion",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_Version));

	registerProperty("getInternalIP",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_InternalIP));

	registerProperty("getUUID",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_UUID));

	registerProperty("getSerial",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_Serial));

	registerProperty("getMBSerial",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_MBSerial));

	registerProperty("getMBManufacturer",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_MBManufacturer));

	registerProperty("getOS",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_OS));

	registerProperty("getOSUsername",
                     make_property(this, &AdvantageDataSecurityPluginAPI::get_OSUsername));

	// registerProperty("adiEncrypt",
    //                 make_property(this, &AdvantageDataSecurityPluginAPI::adiEncrypt));

}

AdvantageDataSecurityPluginAPI::~AdvantageDataSecurityPluginAPI()
{
    //std::map<int,int>::capacity()
}

AdvantageDataSecurityPluginPtr AdvantageDataSecurityPluginAPI::getPlugin()
{
    AdvantageDataSecurityPluginPtr plugin = m_pluginWeak.lock();
    if (!plugin)
        throw FB::script_error("The plugin object has been destroyed");
    return plugin;
}

std::string AdvantageDataSecurityPluginAPI::get_pluginPath()
{
    return getPlugin()->getPluginPath();
}

std::string AdvantageDataSecurityPluginAPI::get_pluginId()
{
    return getPlugin()->getPluginId();
}

std::string AdvantageDataSecurityPluginAPI::get_MACAddress()
{
	return getPlugin()->getMACAddress();
}

std::string AdvantageDataSecurityPluginAPI::get_Version()
{
	return getPlugin()->getVersion();
}

std::string AdvantageDataSecurityPluginAPI::get_InternalIP()
{
	return getPlugin()->getInternalIP();
}

std::string AdvantageDataSecurityPluginAPI::get_UUID()
{
	return getPlugin()->getUUID();
}

std::string AdvantageDataSecurityPluginAPI::get_Serial()
{
	return getPlugin()->getSerial();
}

std::string AdvantageDataSecurityPluginAPI::get_MBSerial()
{
	return getPlugin()->getMBSerial();
}

std::string AdvantageDataSecurityPluginAPI::get_MBManufacturer()
{
	return getPlugin()->getMBManufacturer();
}

std::string AdvantageDataSecurityPluginAPI::get_OS()
{
	return getPlugin()->getOS();
}

std::string AdvantageDataSecurityPluginAPI::get_OSUsername()
{
	return getPlugin()->getOSUsername();
}

std::string AdvantageDataSecurityPluginAPI::adiEncrypt(std::string sInput)
{
	return getPlugin()->adiEncrypt(sInput);
}